from subprocess import PIPE, Popen


def run_pwsh(ps1_file_path):
    try:
        sesh = Popen(
            ["powershell.exe", ps1_file_path], universal_newlines=True, stdout=PIPE
        )
    except Exception as error:
        return error
    finally:
        out, err = sesh.communicate()
        return out, err


def run_pwsh_cmd(command):
    try:
        sesh = Popen(
            ["powershell.exe", command],
            universal_newlines=True,
            stdin=PIPE,
            stdout=PIPE,
        )
    except Exception as error:
        return error
    finally:
        out, err = sesh.communicate()
        return out, err


if __name__ == "__main__":
    run_pwsh()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pipe_viper']

package_data = \
{'': ['*']}

setup_kwargs = {
    'name': 'pipe-viper',
    'version': '0.1.2',
    'description': 'Pwsh utils for python',
    'long_description': '# Pipe Viper Plugin\n\n* This core plugin is meant simply for time savings and only uses the standard Python library, the goal is no additional dependencies.\n* Plugins may take dependencies in the future  \n  \n__Currently only supports running a single `.ps1` or `string` Powershell command.__  \nI plan to add support for command scripts and other shells, as well as supporting libraries of useful script functionality. Though, this plugin will be primarily focused on PowerShell related functionality unless someone else expands on other shell support.\n\n## https://pypi.org/project/pipe-viper/',
    'author': 'Josh S Wilkinson',
    'author_email': 'JoshsWilkinson@Outlook.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/Phelsong/pipe_viper',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
